@@ -1,8 +1,7 @@
-import React, { useState } from 'react';
+import { useState } from 'react';
 
-import { Space } from '@grafana/experimental';
-import { config } from '@grafana/runtime';
-import { Alert, ConfirmModal, Text } from '@grafana/ui';
+import { config, reportInteraction } from '@grafana/runtime';
+import { Alert, ConfirmModal, Text, Space } from '@grafana/ui';
 import { Trans, t } from 'app/core/internationalization';
 
 import { useGetAffectedItemsQuery } from '../../api/browseDashboardsAPI';
@@ -19,9 +18,17 @@ export interface Props {
 
 export const DeleteModal = ({ onConfirm, onDismiss, selectedItems, ...props }: Props) => {
   const { data } = useGetAffectedItemsQuery(selectedItems);
-  const deleteIsInvalid = !config.featureToggles.nestedFolders && data && (data.alertRule || data.libraryPanel);
+  const deleteIsInvalid = Boolean(data && (data.alertRule || data.libraryPanel));
   const [isDeleting, setIsDeleting] = useState(false);
   const onDelete = async () => {
+    reportInteraction('grafana_manage_dashboards_delete_clicked', {
+      item_counts: {
+        dashboard: Object.keys(selectedItems.dashboard).length,
+        folder: Object.keys(selectedItems.folder).length,
+      },
+      source: 'browse_dashboards',
+      restore_enabled: Boolean(config.featureToggles.dashboardRestore),
+    });
     setIsDeleting(true);
     try {
       await onConfirm();
@@ -36,6 +43,18 @@ export const DeleteModal = ({ onConfirm, onDismiss, selectedItems, ...props }: P
     <ConfirmModal
       body={
         <>
+          {config.featureToggles.dashboardRestore && (
+            <>
+              <Text element="p">
+                <Trans i18nKey="browse-dashboards.action.delete-modal-restore-dashboards-text">
+                  This action will delete the selected folders immediately but the selected dashboards will be marked
+                  for deletion in 30 days. Your organization administrator can restore the dashboards anytime before the
+                  30 days expire. Folders cannot be restored.
+                </Trans>
+              </Text>
+              <Space v={2} />
+            </>
+          )}
           <Text element="p">
             <Trans i18nKey="browse-dashboards.action.delete-modal-text">
               This action will delete the following content:
@@ -59,7 +78,7 @@ export const DeleteModal = ({ onConfirm, onDismiss, selectedItems, ...props }: P
           ) : null}
         </>
       }
-      confirmationText="Delete"
+      confirmationText={t('browse-dashboards.action.confirmation-text', 'Delete')}
       confirmText={
         isDeleting
           ? t('browse-dashboards.action.deleting', 'Deleting...')
@@ -69,6 +88,7 @@ export const DeleteModal = ({ onConfirm, onDismiss, selectedItems, ...props }: P
       onConfirm={onDelete}
       title={t('browse-dashboards.action.delete-modal-title', 'Delete')}
       {...props}
+      disabled={deleteIsInvalid}
     />
   );
 };
