@@ -1,14 +1,13 @@
 import { css } from '@emotion/css';
-import React from 'react';
 
 import { FieldConfigOptionsRegistry, GrafanaTheme2, ConfigOverrideRule } from '@grafana/data';
-import { HorizontalGroup, Icon, IconButton, useStyles2 } from '@grafana/ui';
+import { Button, HorizontalGroup, Icon, useStyles2 } from '@grafana/ui';
 import { FieldMatcherUIRegistryItem } from '@grafana/ui/src/components/MatchersUI/types';
 
 interface Props {
   isExpanded: boolean;
   registry: FieldConfigOptionsRegistry;
-  matcherUi: FieldMatcherUIRegistryItem<any>;
+  matcherUi: FieldMatcherUIRegistryItem<ConfigOverrideRule>;
   override: ConfigOverrideRule;
   overrideName: string;
   onOverrideRemove: () => void;
@@ -30,7 +29,14 @@ export const OverrideCategoryTitle = ({
     <div>
       <HorizontalGroup justify="space-between">
         <div>{overrideName}</div>
-        <IconButton name="trash-alt" onClick={onOverrideRemove} tooltip="Remove override" />
+        <Button
+          variant="secondary"
+          fill="text"
+          icon="trash-alt"
+          onClick={onOverrideRemove}
+          tooltip="Remove override"
+          aria-label="Remove override"
+        />
       </HorizontalGroup>
       {!isExpanded && (
         <div className={styles.overrideDetails}>
@@ -47,23 +53,23 @@ OverrideCategoryTitle.displayName = 'OverrideTitle';
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    matcherUi: css`
-      padding: ${theme.spacing(1)};
-    `,
-    propertyPickerWrapper: css`
-      margin-top: ${theme.spacing(2)};
-    `,
-    overrideDetails: css`
-      font-size: ${theme.typography.bodySmall.fontSize};
-      color: ${theme.colors.text.secondary};
-      font-weight: ${theme.typography.fontWeightRegular};
-    `,
-    options: css`
-      overflow: hidden;
-      padding-right: ${theme.spacing(4)};
-    `,
-    unknownLabel: css`
-      margin-bottom: 0;
-    `,
+    matcherUi: css({
+      padding: theme.spacing(1),
+    }),
+    propertyPickerWrapper: css({
+      marginTop: theme.spacing(2),
+    }),
+    overrideDetails: css({
+      fontSize: theme.typography.bodySmall.fontSize,
+      color: theme.colors.text.secondary,
+      fontWeight: theme.typography.fontWeightRegular,
+    }),
+    options: css({
+      overflow: 'hidden',
+      paddingRight: theme.spacing(4),
+    }),
+    unknownLabel: css({
+      marginBottom: 0,
+    }),
   };
 };
