@@ -1,5 +1,3 @@
-import React from 'react';
-
 import { Page } from 'app/core/components/Page/Page';
 import { contextSrv } from 'app/core/core';
 
@@ -14,12 +12,8 @@ export function UserInvitePage() {
   );
 
   return (
-    <Page navId="users" pageNav={{ text: 'Invite user' }} subTitle={subTitle}>
+    <Page navId="global-users" pageNav={{ text: 'Invite user' }} subTitle={subTitle}>
       <Page.Contents>
-        <Page.OldNavOnly>
-          <h3 className="page-sub-heading">Invite user</h3>
-          <div className="p-b-2">{subTitle}</div>
-        </Page.OldNavOnly>
         <UserInviteForm />
       </Page.Contents>
     </Page>
