@@ -13,11 +13,6 @@ import { StoreState, PluginsState } from 'app/types';
 
 export type PluginTypeCode = 'app' | 'panel' | 'datasource';
 
-export enum PluginListDisplayMode {
-  Grid = 'grid',
-  List = 'list',
-}
-
 export enum PluginAdminRoutes {
   Home = 'plugins-home',
   Browse = 'plugins-browse',
@@ -44,8 +39,11 @@ export interface CatalogPlugin extends WithAccessControlMetadata {
   isInstalled: boolean;
   isDisabled: boolean;
   isDeprecated: boolean;
+  isManaged: boolean; // Indicates that the plugin version is managed by Grafana
+  isPreinstalled: { found: boolean; withVersion: boolean }; // Indicates that the plugin is pre-installed
   // `isPublished` is TRUE if the plugin is published to grafana.com
   isPublished: boolean;
+  latestVersion?: string;
   name: string;
   orgName: string;
   signature: PluginSignatureStatus;
@@ -62,7 +60,10 @@ export interface CatalogPlugin extends WithAccessControlMetadata {
   // instance plugins may not be fully installed, which means a new instance
   // running the plugin didn't started yet
   isFullyInstalled?: boolean;
+  isUninstallingFromInstance?: boolean;
+  isUpdatingFromInstance?: boolean;
   iam?: IdentityAccessManagement;
+  isProvisioned?: boolean;
 }
 
 export interface CatalogPluginDetails {
@@ -76,6 +77,8 @@ export interface CatalogPluginDetails {
   pluginDependencies?: PluginDependencies['plugins'];
   statusContext?: string;
   iam?: IdentityAccessManagement;
+  changelog?: string;
+  lastCommitDate?: string;
 }
 
 export interface CatalogPluginInfo {
@@ -87,6 +90,7 @@ export interface CatalogPluginInfo {
 }
 
 export type RemotePlugin = {
+  changelog: string;
   createdAt: string;
   description: string;
   downloads: number;
@@ -136,6 +140,7 @@ export type RemotePlugin = {
   versionSignedByOrgName: string;
   versionStatus: string;
   angularDetected?: boolean;
+  lastCommitDate?: string;
 };
 
 // The available status codes on GCOM are available here:
@@ -154,6 +159,7 @@ export type LocalPlugin = WithAccessControlMetadata & {
   dev?: boolean;
   enabled: boolean;
   hasUpdate: boolean;
+  latestVersion: string;
   id: string;
   info: {
     author: Rel;
@@ -210,6 +216,7 @@ export interface Version {
   createdAt: string;
   isCompatible: boolean;
   grafanaDependency: string | null;
+  angularDetected?: boolean;
 }
 
 export interface PluginDetails {
@@ -248,6 +255,8 @@ export enum PluginTabLabels {
   DASHBOARDS = 'Dashboards',
   USAGE = 'Usage',
   IAM = 'IAM',
+  CHANGELOG = 'Changelog',
+  PLUGINDETAILS = 'Plugin details',
 }
 
 export enum PluginTabIds {
@@ -257,6 +266,8 @@ export enum PluginTabIds {
   DASHBOARDS = 'dashboards',
   USAGE = 'usage',
   IAM = 'iam',
+  CHANGELOG = 'changelog',
+  PLUGINDETAILS = 'right-panel',
 }
 
 export enum RequestStatus {
@@ -286,11 +297,8 @@ export type PluginDetailsTab = {
 
 // TODO<remove `PluginsState &` when the "plugin_admin_enabled" feature flag is removed>
 export type ReducerState = PluginsState & {
-  items: EntityState<CatalogPlugin>;
+  items: EntityState<CatalogPlugin, string>;
   requests: Record<string, RequestInfo>;
-  settings: {
-    displayMode: PluginListDisplayMode;
-  };
 };
 
 // TODO<remove when the "plugin_admin_enabled" feature flag is removed>
@@ -314,8 +322,14 @@ export type PluginVersion = {
   links: Array<{ rel: string; href: string }>;
   isCompatible: boolean;
   grafanaDependency: string | null;
+  angularDetected?: boolean;
 };
 
 export type InstancePlugin = {
   pluginSlug: string;
+  version: string;
+};
+
+export type ProvisionedPlugin = {
+  slug: string;
 };
