@@ -1,5 +1,6 @@
 import { debounce } from 'lodash';
-import React, { useState } from 'react';
+import { useState } from 'react';
+import * as React from 'react';
 
 import { EditorField } from '@grafana/experimental';
 import { Input } from '@grafana/ui';
