@@ -1,4 +1,4 @@
-import { config } from '@grafana/runtime';
+import deepEqual from 'fast-deep-equal';
 
 import { CloudWatchMetricsQuery } from '../types';
 
@@ -6,7 +6,7 @@ import { CloudWatchMetricsQuery } from '../types';
 export function migrateMetricQuery(query: CloudWatchMetricsQuery): CloudWatchMetricsQuery {
   //add metric query migrations here
   const migratedQuery = migrateAliasPatterns(query);
-  return migratedQuery;
+  return deepEqual(migratedQuery, query) ? query : migratedQuery;
 }
 
 const aliasPatterns: Record<string, string> = {
@@ -18,18 +18,22 @@ const aliasPatterns: Record<string, string> = {
   label: `LABEL`,
 };
 
+// migrateAliasPatterns in the context of https://github.com/grafana/grafana/issues/48434
 export function migrateAliasPatterns(query: CloudWatchMetricsQuery): CloudWatchMetricsQuery {
-  if (config.featureToggles.cloudWatchDynamicLabels && !query.hasOwnProperty('label')) {
-    const regex = /{{\s*(.+?)\s*}}/g;
-    query.label =
-      query.alias?.replace(regex, (_, value) => {
-        if (aliasPatterns.hasOwnProperty(value)) {
-          return `\${${aliasPatterns[value]}}`;
-        }
+  if (!query.hasOwnProperty('label')) {
+    const newQuery = { ...query };
+    if (!query.hasOwnProperty('label')) {
+      const regex = /{{\s*(.+?)\s*}}/g;
+      newQuery.label =
+        query.alias?.replace(regex, (_, value) => {
+          if (aliasPatterns.hasOwnProperty(value)) {
+            return `\${${aliasPatterns[value]}}`;
+          }
 
-        return `\${PROP('Dim.${value}')}`;
-      }) ?? '';
+          return `\${PROP('Dim.${value}')}`;
+        }) ?? '';
+    }
+    return newQuery;
   }
-
   return query;
 }
