@@ -1,26 +1,39 @@
 import { css } from '@emotion/css';
 import { useId } from '@react-aria/utils';
 import pluralize from 'pluralize';
-import React, { useCallback, useMemo } from 'react';
+import { useCallback, useMemo } from 'react';
 import { useAsync } from 'react-use';
 
 import { DataQuery, GrafanaTheme2, SelectableValue, DataTopic, QueryEditorProps } from '@grafana/data';
+import { OperationsEditorRow } from '@grafana/experimental';
 import { Field, Select, useStyles2, Spinner, RadioButtonGroup, Stack, InlineSwitch } from '@grafana/ui';
 import config from 'app/core/config';
 import { getDashboardSrv } from 'app/features/dashboard/services/DashboardSrv';
-import { PanelModel } from 'app/features/dashboard/state';
+import { PanelModel } from 'app/features/dashboard/state/PanelModel';
+import { DashboardScene } from 'app/features/dashboard-scene/scene/DashboardScene';
 import { getDatasourceSrv } from 'app/features/plugins/datasource_srv';
 import { filterPanelDataToQuery } from 'app/features/query/components/QueryEditorRow';
 
-import { OperationsEditorRow } from '../prometheus/querybuilder/shared/OperationsEditorRow';
+import { MIXED_DATASOURCE_NAME } from '../mixed/MixedDataSource';
 
+import { SHARED_DASHBOARD_QUERY } from './constants';
 import { DashboardDatasource } from './datasource';
-import { DashboardQuery, ResultInfo, SHARED_DASHBOARD_QUERY } from './types';
+import { DashboardQuery, ResultInfo } from './types';
 
 function getQueryDisplayText(query: DataQuery): string {
   return JSON.stringify(query);
 }
 
+function isPanelInEdit(panelId: number, panelInEditId?: number) {
+  let idToCompareWith = panelInEditId;
+
+  if (window.__grafanaSceneContext && window.__grafanaSceneContext instanceof DashboardScene) {
+    idToCompareWith = window.__grafanaSceneContext.state.editPanel?.getPanelId();
+  }
+
+  return panelId === idToCompareWith;
+}
+
 interface Props extends QueryEditorProps<DashboardDatasource, DashboardQuery> {}
 
 const topics = [
@@ -28,6 +41,8 @@ const topics = [
   { label: 'Annotations', value: true, description: 'Include annotations as regular data' },
 ];
 
+export const INVALID_PANEL_DESCRIPTION = 'Contains a shared dashboard query';
+
 export function DashboardQueryEditor({ data, query, onChange, onRunQuery }: Props) {
   const { value: defaultDatasource } = useAsync(() => getDatasourceSrv().get());
 
@@ -93,6 +108,13 @@ export function DashboardQueryEditor({ data, query, onChange, onRunQuery }: Prop
     [query, onUpdateQuery]
   );
 
+  const isMixedDSWithDashboardQueries = (panel: PanelModel) => {
+    return (
+      panel.datasource?.uid === MIXED_DATASOURCE_NAME &&
+      panel.targets.some((t) => t.datasource?.uid === SHARED_DASHBOARD_QUERY)
+    );
+  };
+
   const getPanelDescription = useCallback(
     (panel: PanelModel): string => {
       const datasource = panel.datasource ?? defaultDatasource;
@@ -109,18 +131,24 @@ export function DashboardQueryEditor({ data, query, onChange, onRunQuery }: Prop
     () =>
       dashboard?.panels
         .filter(
-          (panel) =>
-            config.panels[panel.type] &&
-            panel.targets &&
-            panel.id !== dashboard.panelInEdit?.id &&
-            panel.datasource?.uid !== SHARED_DASHBOARD_QUERY
+          (panel) => config.panels[panel.type] && panel.targets && !isPanelInEdit(panel.id, dashboard.panelInEdit?.id)
         )
-        .map((panel) => ({
-          value: panel.id,
-          label: panel.title ?? 'Panel ' + panel.id,
-          description: getPanelDescription(panel),
-          imgUrl: config.panels[panel.type].info.logos.small,
-        })) ?? [],
+        .map((panel) => {
+          let description = getPanelDescription(panel);
+          let isDisabled = false;
+          if (panel.datasource?.uid === SHARED_DASHBOARD_QUERY || isMixedDSWithDashboardQueries(panel)) {
+            description = INVALID_PANEL_DESCRIPTION;
+            isDisabled = true;
+          }
+
+          return {
+            value: panel.id,
+            label: panel.title ?? 'Panel ' + panel.id,
+            imgUrl: config.panels[panel.type].info.logos.small,
+            description,
+            isDisabled,
+          };
+        }) ?? [],
     [dashboard, getPanelDescription]
   );
 
